<?php
/**
 * Custom template tags for this theme
 *
 * @package Calibration
 * @since 1.0.0
 * @version 1.0.0
 */

if ( ! function_exists( 'calibration_posts_navigation' ) ) :
/**
 * Displays the navigation to next/previous post, when applicable.
 *
 * Technically, a wrapper around get_the_posts_navigation()
 *
 * @since 1.0.0
 *
 * @param array $args Optional. Default empty array.
 */
function calibration_posts_navigation( $args = array() ) {
	
	/**
	 * Filters the arguments of posts navigation
	 *
	 * @since 1.0.0
	 *
	 * @param array $args Arguments for posts navigation function.
	 */
	$args = apply_filters( 'calibration_posts_navigation_args', $args );

	echo get_the_posts_navigation( $args );
}
endif;

if ( ! function_exists( 'calibration_has_header_image' ) ) :
/**
 * Determine if custom header image exists and was not removed
 *
 * The appearence of header and related <body> class can be filtered now.
 *
 * @since 1.0.0
 *
 * @param void
 * @return bool True if image exists and was not removed, false otherwise.
 */
function calibration_has_header_image() {
	if ( ! has_header_image() ) :
		return false;
	endif;

	return (bool) apply_filters( 'calibration_has_header_image', true );
}
endif;

if ( ! function_exists( 'calibration_content_format_gallery' ) ) :
/**
 * Extract first gallery shortcode from the content to use it in the template
 *
 * @since 1.0.0
 *
 * @param string $more_link_text Optional. Content for when there is more text.
 * @param bool   $strip_teaser   Optional. Strip teaser content before the more text. Default is false.
 * @return array Raw content of the post and the first gallery shortcode found in the content
 */
function calibration_content_format_gallery( $more_link_text = null, $strip_teaser = false ) {
	$content = get_the_content( $more_link_text, $strip_teaser );
	$content_gallery = array( 'content' => str_replace( ']]>', ']]&gt;', $content ), 'gallery' => '' );
	
	preg_match_all( '/'. get_shortcode_regex() .'/s', $content, $matches, PREG_SET_ORDER );
	
	if ( ! empty( $matches ) ) :
		foreach ( $matches as $shortcode ) :
			if ( 'gallery' === $shortcode[2] ) :
				$content_gallery['gallery'] = $shortcode[0];
				// Store content without the extracted shortcode
				$pos = strpos( $content, $shortcode[0] );
				if ( false !== $pos ) :
					$content_gallery['content'] = substr_replace( $content, '', $pos, strlen( $shortcode[0] ) );
					break;
				endif;
			endif;
		endforeach;
	endif;

	return $content_gallery;
}
endif;

if ( ! function_exists( 'calibration_the_author' ) ) :
/**
 * Display the post author
 *
 * @since 1.0.0
 *
 * @return void
 */
function calibration_the_author() {
		$output  = "<div class=\"post-author\">\n";
		$output .= sprintf( "<span class=\"author-label\">%1s</span>\n%2s\n<span class=\"author-name\">%3s</span>\n<p>%4s</p>\n<a class=\"author-posts\" href=\"%5s\">%6s</a>\n",
			esc_html__( 'Author:', 'calibration' ),
			get_avatar( get_the_author_meta( 'ID' ) ),
			esc_html( get_the_author() ),
			get_the_author_meta( 'description' ),
			get_author_posts_url( get_the_author_meta( 'ID' ) ),
			esc_html__( 'View posts', 'calibration' ) );
		if ( get_the_author_meta( 'url' ) )
			$output .= sprintf( "<a class=\"author-url\" href=\"%1s\" target=\"_blank\">%2s</a>\n",
				get_the_author_meta( 'url' ),
				esc_html__( 'Visit website', 'calibration' ) );
		$output .= "</div>\n";

	/**
	 * Filters the post author HTML
	 *
	 * @since 1.0.0
	 *
	 * @param string $output Author info code.
	 */
	$output = apply_filters( 'calibration_the_author_html', $output );

	echo $output;
}
endif;

if ( ! function_exists( 'calibration_entry_date' ) ) :
/**
 * Display entry date wrapped in <time> tag
 *
 * @since 1.0.0
 *
 * @return void
 */
function calibration_entry_date() {
	$date = sprintf( '<time class="entry-date" datetime="%1$s">%2$s</time>',
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ) 
	);
	if ( ! is_single() && '' == get_the_title() ) :
		$date = '<a href="' . get_permalink() . '">' . $date . '</a>';
	endif;

	echo $date;
}
endif;

if ( ! function_exists( 'calibration_get_footer_content' ) ) :
/**
 * Get the content for the site footer
 *
 * @since 1.0.0
 *
 * @return string The content of the footer. Comes from theme mod, filter hook or defaults.
 */
function calibration_get_footer_content() {

	/**
	 * Filters the default footer content output.
	 *
	 * If the filtered output isn't empty, it will be used instead of generating
	 * the default footer content template.
	 *
	 * @since 1.0.0
	 *
	 * @param string $output   The footer content. Default empty.
	 */
	$output = apply_filters( 'calibration_footer_content', '' );
	if ( '' != $output ) :
		return $output;
	endif;

	$calibration_theme_mods = calibration_get_theme_mods();

	$output  = "<h3 class=\"footer-title\">" . nl2br( calibration_sanitize_linked_text( $calibration_theme_mods['calibration_footer_title'] ) ) . "</h3>\n";
	$output .= "<div class=\"footer-content\">\n";
	if ( ( $calibration_theme_mods['calibration_show_privacy_policy'] || is_customize_preview() ) && function_exists( 'get_the_privacy_policy_link' ) ) :
		$output .= get_the_privacy_policy_link();
	endif;
	$output .= "<p class=\"footer-entry\">" . nl2br( calibration_sanitize_linked_text( $calibration_theme_mods['calibration_footer_entry'] ) );
	$output .= "</p>\n";
	$output .= "</div>\n";

	return $output;
}
endif;

if ( ! function_exists( 'calibration_footer_content' ) ) :
/**
 * Display the footer content
 *
 * @since 1.0.0
 *
 * @return void
 */
function calibration_footer_content() {
	echo calibration_get_footer_content();
}
endif;

if ( ! function_exists( 'calibration_is_front' ) ) :
/**
 * Determine if we're on the front page
 *
 * @since 1.0.0
 *
 * @global $wp_query
 * @return boolean
 */
function calibration_is_front() {
	global $wp_query;

	return is_front_page() || ( is_home() && ! $wp_query->is_posts_page );
}
endif;

if ( ! function_exists( 'calibration_is_empty_search' ) ) :
/**
 * Determine if we're on search page with empty results
 *
 * @since 1.0.0
 *
 * @global $wp_query
 * @return boolean
 */
function calibration_is_empty_search() {
	if ( ! is_search() ) :
		return false;
	endif;

	global $wp_query;

	$result = ( 0 == $wp_query->found_posts ) ? true : false;

	return $result;
}
endif;
